==> haskell-monad-control-1.0.2.3-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.3
id: monad-control-1.0.2.3-DXP4ByOEjHJ5rVzR8ITkTD
key: monad-control-1.0.2.3-DXP4ByOEjHJ5rVzR8ITkTD
license: BSD-3-Clause
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
abi: 30c3af84788004e60b8a1c73a93d8faa
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-control-1.0.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-control-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-control-1.0.2.3
hs-libraries: HSmonad-control-1.0.2.3-DXP4ByOEjHJ5rVzR8ITkTD
depends:
    base-4.12.0.0 stm-2.5.0.0 transformers-0.5.6.2
    transformers-base-0.4.5.2-KiogS5KFFp4IwxvJXTI1QL
    transformers-compat-0.6.4-3mIoeQKAFq789cuQC8bUpt
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-control-1.0.2.3-36-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-control.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-control
version: 1.0.2.3
id: monad-control-1.0.2.3-FeYEsm8P5694VImLZDBXYS
key: monad-control-1.0.2.3-FeYEsm8P5694VImLZDBXYS
license: BSD-3-Clause
copyright: (c) 2011 Bas van Dijk, Anders Kaseorg
maintainer: Bas van Dijk <v.dijk.bas@gmail.com>
author: Bas van Dijk, Anders Kaseorg
homepage: https://github.com/basvandijk/monad-control
synopsis: Lift control operations, like exception catching, through monad transformers
description:
    This package defines the type class @MonadBaseControl@, a subset of
    @MonadBase@ into which generic control operations such as @catch@ can be
    lifted from @IO@ or any other base monad. Instances are based on monad
    transformers in @MonadTransControl@, which includes all standard monad
    transformers in the @transformers@ library except @ContT@.
    .
    See the <http://hackage.haskell.org/package/lifted-base lifted-base>
    package which uses @monad-control@ to lift @IO@
    operations from the @base@ library (like @catch@ or @bracket@) into any monad
    that is an instance of @MonadBase@ or @MonadBaseControl@.
    .
    Note that this package is a rewrite of Anders Kaseorg'\''s @monad-peel@
    library. The main difference is that this package provides CPS style operators
    and exploits the @RankNTypes@ and @TypeFamilies@ language extensions to
    simplify and speedup most definitions.
category: Control
abi: 52438a76959ac51a0475853d2434f5ac
exposed: True
exposed-modules:
    Control.Monad.Trans.Control
import-dirs: /usr/lib/ghc-8.6.5/site-local/monad-control-1.0.2.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/monad-control-1.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/monad-control-1.0.2.3
hs-libraries: HSmonad-control-1.0.2.3-FeYEsm8P5694VImLZDBXYS
depends:
    base-4.12.0.0 stm-2.5.0.0 transformers-0.5.6.2
    transformers-base-0.4.5.2-HGTy7PtJMWjITFSZBfRdND
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
haddock-interfaces: /usr/share/doc/haskell-monad-control/html/monad-control.haddock
haddock-html: /usr/share/doc/haskell-monad-control/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
